package thesis.gui;

import java.awt.Font;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.GroupLayout;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.SwingConstants;
import javax.swing.LayoutStyle.ComponentPlacement;

import thesis.gui.icons.Icons;

public final class MainFrame extends JFrame {

  private static final long serialVersionUID = 1L;
  
  public MainFrame() {
    super("Simulacija gibanja nebeskih tijela");
    setDefaultCloseOperation(EXIT_ON_CLOSE);
    
    setResizable(false);
    setContentPane(createContentPanel());
    pack();
    setLocationRelativeTo(null);
  }
  
  private JButton createButton(String text, String iconName) {
    JButton button = new JButton(text, Icons.load(iconName));
    Font font = button.getFont().deriveFont(button.getFont().getSize() * 1.5f);
    
    button.setFont(font);
    button.setHorizontalTextPosition(SwingConstants.CENTER);
    button.setVerticalTextPosition(SwingConstants.TOP);
    return button;
  }

  private JPanel createContentPanel() {
    JButton modelButton = createButton("Model", "model.png");
    modelButton.addActionListener(new ActionListener() {
      @Override
      public void actionPerformed(ActionEvent e) {
        new ModelDialog(MainFrame.this).setVisible(true);
      }
    });
    
    JButton simulationButton = createButton("Simulacija", "simulation.png");
    simulationButton.addActionListener(new ActionListener() {
      @Override
      public void actionPerformed(ActionEvent e) {
        new SimulationDialog(MainFrame.this).setVisible(true);
      }
    });
    
    JButton videoButton = createButton("Video", "video.png");
    videoButton.addActionListener(new ActionListener() {
      @Override
      public void actionPerformed(ActionEvent e) {
        new VideoDialog(MainFrame.this).setVisible(true);
      }
    });
    
    JPanel panel = new JPanel();
    GroupLayout layout = new GroupLayout(panel);
    panel.setLayout(layout);
    
    layout.setHorizontalGroup(layout.createSequentialGroup()
      .addContainerGap()
      .addComponent(modelButton)
      .addPreferredGap(ComponentPlacement.UNRELATED)
      .addComponent(simulationButton)
      .addPreferredGap(ComponentPlacement.UNRELATED)
      .addComponent(videoButton)
      .addContainerGap()
    );
    
    layout.setVerticalGroup(layout.createSequentialGroup()
      .addContainerGap()
      .addGroup(layout.createParallelGroup()
        .addComponent(modelButton)
        .addComponent(simulationButton)
        .addComponent(videoButton)
      )
      .addContainerGap()
    );
    
    return panel;
  }

}
