package thesis.tree;

public final class Vector {

  private final float x;
  private final float y;

  public Vector() {
    this(0.0f, 0.0f);
  }
  
  public Vector(float x, float y) {
    this.x = x;
    this.y = y;
  }

  public Vector add(Vector other) {
    return new Vector(x + other.x, y + other.y);
  }

  public Vector subtract(Vector other) {
    return new Vector(x - other.x, y - other.y);
  }
  
  public Vector multiply(float scale) {
    return new Vector(x * scale, y * scale);
  }
  
  public Vector divide(float scale) {
    return new Vector(x / scale, y / scale);
  }
  
  public float length() {
    return (float)Math.sqrt(x * x + y * y);
  }
  
  public float angle() {
    return (float)Math.atan2(y, x);
  }
  
  public boolean equals(Vector other) {
    return x == other.x && y == other.y;
  }
  
  @Override
  public String toString() {
    return x + " ; " + y;
  }
  
  public float getX() {
    return x;
  }
  
  public float getY() {
    return y;
  }

}
